BillsModel class

Constructors

BillsModel({required double amount, required DateTime createdAt, String? customerId, required String customerName, required DateTime dueDate, String? id, required DateTime issueDate, required String referenceNumber, required int unitsConsumed, required DateTime updatedAt})
BillsModel.fromJson(Map<String, dynamic> json)
factory

Properties

amount double
final
createdAt DateTime
final
customerId String?
final
customerName String
final
dueDate DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
issueDate DateTime
final
referenceNumber String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unitsConsumed int
final
updatedAt DateTime
final

Methods

copyWith({double? amount, DateTime? createdAt, String? customerId, String? customerName, DateTime? dueDate, String? id, DateTime? issueDate, String? referenceNumber, int? unitsConsumed, DateTime? updatedAt}) BillsModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited