BracketCostsModel class

Constructors

BracketCostsModel({required double acCable, required double accessories, required DateTime createdAt, required double dcCable, String? id, required double maxSize, required double minSize, required DateTime updatedAt})
BracketCostsModel.fromJson(Map<String, dynamic> json)
factory

Properties

acCable double
final
accessories double
final
createdAt DateTime
final
dcCable double
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
maxSize double
final
minSize double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
final

Methods

copyWith({double? acCable, double? accessories, DateTime? createdAt, double? dcCable, String? id, double? maxSize, double? minSize, DateTime? updatedAt}) BracketCostsModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited