CustomersModel class

Constructors

CustomersModel({required String address, required DateTime createdAt, required DateTime date, String? id, required String name, required String phone, required String referenceNumber, required DateTime updatedAt})
CustomersModel.fromJson(Map<String, dynamic> json)
factory

Properties

address String
final
createdAt DateTime
final
date DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
name String
final
phone String
final
referenceNumber String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
final

Methods

copyWith({String? address, DateTime? createdAt, DateTime? date, String? id, String? name, String? phone, String? referenceNumber, DateTime? updatedAt}) CustomersModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited