DocumentsModel class

Constructors

DocumentsModel({required DateTime createdAt, String? id, Map<String, dynamic>? metadata, required String name, required String path, String? referenceNumber, int? size, required String type, required DateTime updatedAt, required String url})
DocumentsModel.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
metadata Map<String, dynamic>?
final
name String
final
path String
final
referenceNumber String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
final
type String
final
updatedAt DateTime
final
url String
final

Methods

copyWith({DateTime? createdAt, String? id, Map<String, dynamic>? metadata, String? name, String? path, String? referenceNumber, int? size, String? type, DateTime? updatedAt, String? url}) DocumentsModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited