QuoteVersionsModel class

Constructors

QuoteVersionsModel({required Map<String, dynamic> calculations, DateTime? createdAt, String? id, required String quoteId})
QuoteVersionsModel.fromJson(Map<String, dynamic> json)
factory

Properties

calculations Map<String, dynamic>
final
createdAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
quoteId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Map<String, dynamic>? calculations, DateTime? createdAt, String? id, String? quoteId}) QuoteVersionsModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited