VariableCostsModel class

Constructors

VariableCostsModel({required double cost, required String costName, required DateTime createdAt, String? id, required DateTime updatedAt})
VariableCostsModel.fromJson(Map<String, dynamic> json)
factory

Properties

cost double
final
costName String
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
final

Methods

copyWith({double? cost, String? costName, DateTime? createdAt, String? id, DateTime? updatedAt}) VariableCostsModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited