DocumentsRepository class

Repository for the documents table

Inheritance

Constructors

DocumentsRepository(SupabaseClient client)
const

Properties

client → SupabaseClient
The Supabase client instance used for database operations
finalinherited
hashCode int
The hash code for this object.
no setterinherited
query → SupabaseQueryBuilder
Returns the base query builder for this table
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
The name of the table this repository operates on
finalinherited

Methods

delete(String id) Future<void>
Delete a record by its primary key
find(String id) Future<DocumentsModel?>
Find a record by its primary key
findAll({int? limit, int? offset, String? orderBy, bool ascending = true, Map<String, dynamic>? filters}) Future<List<DocumentsModel>>
Retrieves all records from this table with support for:
override
fromJson(Map<String, dynamic> json) DocumentsModel
Converts a JSON map to a model instance of type T
override
insert(DocumentsModel model) Future<DocumentsModel>
Insert a new record
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(DocumentsModel model) Future<DocumentsModel?>
Update an existing record
upsert(DocumentsModel model) Future<DocumentsModel>
Insert or update a record

Operators

operator ==(Object other) bool
The equality operator.
inherited