PanelsModel class
Constructors
Properties
- availability → bool?
-
final
- brand → String
-
final
- createdAt → DateTime
-
final
- defaultChoice → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- power → double
-
final
- price → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime
-
final
Methods
-
copyWith(
{bool? availability, String? brand, DateTime? createdAt, bool? defaultChoice, String? id, double? power, double? price, DateTime? updatedAt}) → PanelsModel -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited