QuotesModel class
Constructors
Properties
- billId → String
-
final
-
calculations
→ Map<
String, dynamic> -
final
- createdAt → DateTime
-
final
- customerEmail → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemSize → double
-
final
- totalCost → double
-
final
- updatedAt → DateTime
-
final
Methods
-
copyWith(
{String? billId, Map< String, dynamic> ? calculations, DateTime? createdAt, String? customerEmail, String? id, double? systemSize, double? totalCost, DateTime? updatedAt}) → QuotesModel -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited