QuoteVersionsRepository class
Repository for the quote_versions table
- Inheritance
-
- Object
- BaseRepository<
QuoteVersionsModel> - QuoteVersionsRepository
Constructors
- QuoteVersionsRepository(SupabaseClient client)
-
const
Properties
- client → SupabaseClient
-
The Supabase client instance used for database operations
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- query → SupabaseQueryBuilder
-
Returns the base query builder for this table
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableName → String
-
The name of the table this repository operates on
finalinherited
Methods
-
delete(
String id) → Future< void> - Delete a record by its primary key
-
find(
String id) → Future< QuoteVersionsModel?> - Find a record by its primary key
-
findAll(
{int? limit, int? offset, String? orderBy, bool ascending = true, Map< String, dynamic> ? filters}) → Future<List< QuoteVersionsModel> > -
Retrieves all records from this table with support for:
override
-
findByQuoteId(
String quoteId) → Future< List< QuotesModel> > - Find related quotes records based on the quote_id foreign key
-
findByQuoteIdField(
String quoteId, {int? limit, int? offset, String? orderBy, bool ascending = true, Map< String, dynamic> ? additionalFilters}) → Future<List< QuoteVersionsModel> > - Find quote_versions records by quote_id with support for pagination, sorting, and additional filters
-
fromJson(
Map< String, dynamic> json) → QuoteVersionsModel -
Converts a JSON map to a model instance of type T
override
-
insert(
QuoteVersionsModel model) → Future< QuoteVersionsModel> - Insert a new record
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
QuoteVersionsModel model) → Future< QuoteVersionsModel?> - Update an existing record
-
upsert(
QuoteVersionsModel model) → Future< QuoteVersionsModel> - Insert or update a record
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited